==> php83-nextcloud-26.0.5.tgz: share/nextcloud/apps/comments/l10n/sr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Искоментарисали сте",
    "{author} commented" : "{author} коментарисао",
    "You commented on %1$s" : "Коментарисали сте на %1$s",
    "You commented on {file}" : "Коментаристали сте на {file}",
    "%1$s commented on %2$s" : "%1$s коментарисао на %2$s",
    "{author} commented on {file}" : "{author} коментарисао на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> на фајлове",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Поменути сте за „{file}”, у коментару корисника које је од тада обрисан",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} вас је поменуо у коментару за „{file}",
    "Files app plugin to add comments to files" : "Додатак апликацији за фајлове да додајете коментаре на фајлове",
    "Edit comment" : "Измени коментар",
    "Delete comment" : "Обриши коментар",
    "Cancel edit" : "Поништи измену",
    "Post comment" : "Објави коментар",
    "No comments yet, start the conversation!" : "Још нема коментара. Започните дискусију!",
    "No more messages" : "Нема више порука",
    "Retry" : "Покушај поново",
    "Failed to mark comments as read" : "Није успело означавање коментара као прочитаних",
    "Unable to load the comments list" : "Не могуи да учитам списак коментара",
    "_%n unread comment_::_%n unread comments_" : ["%nнепрочитани коментар","%nнепрочитана коментара ","%n непрочитаних коментара"],
    "_1 new comment_::_{unread} new comments_" : ["1 нови коментар","{unread} нова коментара","{unread} нова коментара"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Грешка приликом покушаја мењања коментара",
    "Comment deleted" : "Коментар обрисан",
    "An error occurred while trying to delete the comment" : "Грешка приликом покушаја брисања коментара",
    "An error occurred while trying to create the comment" : "Грешка приликом покушаја креирања коментара",
    "%1$s commented" : "%1$s коментарисао"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> php83-nextcloud-30.0.5.tgz: share/nextcloud/apps/comments/l10n/sr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Искоментарисали сте",
    "{author} commented" : "{author} коментарисао",
    "You commented on %1$s" : "Коментарисали сте на %1$s",
    "You commented on {file}" : "Коментаристали сте на {file}",
    "%1$s commented on %2$s" : "%1$s коментарисао на %2$s",
    "{author} commented on {file}" : "{author} коментарисао на {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> на фајлове",
    "Files" : "Фајлови",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Поменути сте за „{file}”, у коментару налога који је касније обрисан",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} вас је поменуо у коментару за „{file}",
    "Files app plugin to add comments to files" : "Додатак апликацији за фајлове да додајете коментаре на фајлове",
    "Edit comment" : "Измени коментар",
    "Delete comment" : "Обриши коментар",
    "Cancel edit" : "Поништи измену",
    "New comment" : "Нови коментар",
    "Write a comment …" : "Напишите коментар…",
    "Post comment" : "Објави коментар",
    "@ for mentions, : for emoji, / for smart picker" : "@ за помињања, : за емођи, / за паметни бирач",
    "Could not reload comments" : "Коментари не могу поново да се учитају",
    "No comments yet, start the conversation!" : "Још нема коментара. Започните дискусију!",
    "No more messages" : "Нема више порука",
    "Retry" : "Покушај поново",
    "Failed to mark comments as read" : "Није успело означавање коментара као прочитаних",
    "Unable to load the comments list" : "Не могуи да учитам списак коментара",
    "_1 new comment_::_{unread} new comments_" : ["1 нови коментар","{unread} нова коментара","{unread} нова коментара"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Грешка приликом покушаја мењања коментара",
    "Comment deleted" : "Коментар обрисан",
    "An error occurred while trying to delete the comment" : "Грешка приликом покушаја брисања коментара",
    "An error occurred while trying to create the comment" : "Грешка приликом покушаја креирања коментара",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Поменути сте за „{file}”, у коментару корисника које је од тада обрисан"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
